@@ -35,6 +35,9 @@ class Base(object):
     #: setting labels
     x_axis_label = y_axis_label = None
 
+    #: Experimental
+    additional_line_values = False
+
     def __init__(self, target_width=DEFAULT_TARGET_WIDTH):
         if type(target_width) is not int:
             geometric_width, geometric_height = target_width.split('x')
@@ -79,6 +82,8 @@ class Base(object):
         self.left_margin = DEFAULT_MARGIN
         self.right_margin = DEFAULT_MARGIN
         self.legend_margin = LEGEND_MARGIN
+
+        #: Blank space below the title
         self.title_margin = TITLE_MARGIN
 
         self.legend_box_size = 20.0
@@ -92,7 +97,6 @@ class Base(object):
         self.center_labels_over_point = True
         self.has_left_labels = False
 
-        self.additional_line_values = []
         self.additional_line_colors = []
         self.theme_options = {}
 
@@ -277,6 +281,8 @@ class Base(object):
                 continue
             if self.maximum_value is None and self.minimum_value is None:
                 self.maximum_value = self.minimum_value = data_point
+                if self.minimum_value >= 0:
+                    self.minimum_value = 0
             # TODO Doesn't work with stacked bar graphs
             if self.larger_than_max(data_point):
                 self.maximum_value = data_point
@@ -685,7 +691,7 @@ class Base(object):
                self.center_labels_over_point:
                 extra_room_for_long_label = \
                         self.calculate_width(self.marker_font_size,
-                                             self.labels[last_label])
+                                             self.labels[last_label]) / 2.0
             else:
                 extra_room_for_long_label = 0
             self.graph_right_margin = self.right_margin + extra_room_for_long_label
